operator / method
This operator divides a polynomial by another polynomial using the polynomial long division algorithm. The returned AlgebraicDivision type is a record type that contains both the quotient and the remainder of the division.
The algorithm used to divide polynomials is implemented by the PolynomialLongDivision class.
Implementation
AlgebraicDivision operator /(Algebraic other) {
final polyLongDivison = PolynomialLongDivision(
polyNumerator: this,
polyDenominator: other,
);
return polyLongDivison.divide();
}